@@ -21,7 +21,7 @@ describe 'trove::conductor' do
         is_expected.to contain_package('trove-conductor').with(
           :name   => platform_params[:conductor_package_name],
           :ensure => 'present',
-          :notify => 'Service[trove-conductor]'
+          :tag    => ['openstack', 'trove-package'],
         )
       end
 
@@ -31,6 +31,11 @@ describe 'trove::conductor' do
         is_expected.to contain_trove_conductor_config('DEFAULT/nova_proxy_admin_user').with_value('admin')
         is_expected.to contain_trove_conductor_config('DEFAULT/nova_proxy_admin_pass').with_value('verysecrete')
         is_expected.to contain_trove_conductor_config('DEFAULT/nova_proxy_admin_tenant_name').with_value('admin')
+        is_expected.to contain_trove_conductor_config('oslo_messaging_rabbit/rabbit_userid').with_value('guest')
+        is_expected.to contain_trove_conductor_config('oslo_messaging_rabbit/rabbit_password').with_value('guest')
+        is_expected.to contain_trove_conductor_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(false)
+        is_expected.to contain_trove_conductor_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_conductor_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(false)
       end
 
       context 'when using a single RabbitMQ server' do
@@ -41,6 +46,23 @@ describe 'trove::conductor' do
         end
         it 'configures trove-conductor with RabbitMQ' do
           is_expected.to contain_trove_conductor_config('oslo_messaging_rabbit/rabbit_host').with_value('10.0.0.1')
+          is_expected.to contain_trove_conductor_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('false')
+          is_expected.to contain_trove_conductor_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('false')
+        end
+      end
+
+      context 'when using a single RabbitMQ server with enable ha options' do
+        let :pre_condition do
+          "class { 'trove':
+             nova_proxy_admin_pass => 'verysecrete',
+             rabbit_ha_queues      => 'true',
+             amqp_durable_queues   => 'true',
+             rabbit_host           => '10.0.0.1'}"
+        end
+        it 'configures trove-api with RabbitMQ' do
+          is_expected.to contain_trove_conductor_config('oslo_messaging_rabbit/rabbit_host').with_value('10.0.0.1')
+          is_expected.to contain_trove_conductor_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true')
+          is_expected.to contain_trove_conductor_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('true')
         end
       end
 
@@ -52,43 +74,7 @@ describe 'trove::conductor' do
         end
         it 'configures trove-conductor with RabbitMQ' do
           is_expected.to contain_trove_conductor_config('oslo_messaging_rabbit/rabbit_hosts').with_value(['10.0.0.1,10.0.0.2'])
-        end
-      end
-
-      context 'when using qpid' do
-        let :pre_condition do
-          "class { 'trove':
-             nova_proxy_admin_pass => 'verysecrete',
-             rpc_backend           => 'qpid',
-             qpid_hostname         => '10.0.0.1',
-             qpid_username         => 'guest',
-             qpid_password         => 'password'}"
-        end
-        it 'configures trove-conductor with qpid' do
-          is_expected.to contain_trove_conductor_config('DEFAULT/rpc_backend').with_value('qpid')
-          is_expected.to contain_trove_conductor_config('oslo_messaging_qpid/qpid_hostname').with_value('10.0.0.1')
-          is_expected.to contain_trove_conductor_config('oslo_messaging_qpid/qpid_username').with_value('guest')
-          is_expected.to contain_trove_conductor_config('oslo_messaging_qpid/qpid_password').with_value('password')
-          is_expected.to contain_trove_conductor_config('oslo_messaging_qpid/qpid_protocol').with_value('tcp')
-        end
-      end
-
-      context 'when using qpid with SSL enabled' do
-        let :pre_condition do
-          "class { 'trove':
-             nova_proxy_admin_pass => 'verysecrete',
-             rpc_backend           => 'qpid',
-             qpid_hostname         => '10.0.0.1',
-             qpid_username         => 'guest',
-             qpid_password         => 'password',
-             qpid_protocol         => 'ssl'}"
-        end
-        it 'configures trove-conductor with qpid' do
-          is_expected.to contain_trove_conductor_config('DEFAULT/rpc_backend').with_value('qpid')
-          is_expected.to contain_trove_conductor_config('oslo_messaging_qpid/qpid_hostname').with_value('10.0.0.1')
-          is_expected.to contain_trove_conductor_config('oslo_messaging_qpid/qpid_username').with_value('guest')
-          is_expected.to contain_trove_conductor_config('oslo_messaging_qpid/qpid_password').with_value('password')
-          is_expected.to contain_trove_conductor_config('oslo_messaging_qpid/qpid_protocol').with_value('ssl')
+          is_expected.to contain_trove_conductor_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true')
         end
       end
 
@@ -161,8 +147,10 @@ describe 'trove::conductor' do
 
   context 'on Debian platforms' do
     let :facts do
-      { :osfamily       => 'Debian',
-        :processorcount => 8 }
+      @default_facts.merge({
+        :osfamily       => 'Debian',
+        :processorcount => 8,
+      })
     end
 
     let :platform_params do
@@ -175,8 +163,10 @@ describe 'trove::conductor' do
 
   context 'on RedHat platforms' do
     let :facts do
-      { :osfamily       => 'RedHat',
-        :processorcount => 8 }
+      @default_facts.merge({
+        :osfamily       => 'RedHat',
+        :processorcount => 8,
+      })
     end
 
     let :platform_params do
