@@ -22,7 +22,7 @@ describe 'trove::guestagent' do
         is_expected.to contain_package('trove-guestagent').with(
           :name   => platform_params[:guestagent_package_name],
           :ensure => 'present',
-          :notify => 'Service[trove-guestagent]'
+          :tag    => ['openstack', 'trove-package']
         )
       end
 
@@ -33,6 +33,13 @@ describe 'trove::guestagent' do
         is_expected.to contain_trove_guestagent_config('DEFAULT/nova_proxy_admin_pass').with_value('verysecrete')
         is_expected.to contain_trove_guestagent_config('DEFAULT/nova_proxy_admin_tenant_name').with_value('admin')
         is_expected.to contain_trove_guestagent_config('DEFAULT/os_region_name').with_value('RegionOne')
+        is_expected.to contain_trove_guestagent_config('DEFAULT/notification_driver').with_value('noop,')
+        is_expected.to contain_trove_guestagent_config('DEFAULT/notification_topics').with_value('notifications')
+        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_userid').with_value('guest')
+        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_password').with_value('guest')
+        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(false)
+        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(false)
       end
 
       context 'when using a single RabbitMQ server' do
@@ -43,6 +50,23 @@ describe 'trove::guestagent' do
         end
         it 'configures trove-guestagent with RabbitMQ' do
           is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_host').with_value('10.0.0.1')
+          is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('false')
+          is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('false')
+        end
+      end
+
+      context 'when using a single RabbitMQ server with enable ha options' do
+        let :pre_condition do
+          "class { 'trove':
+             nova_proxy_admin_pass => 'verysecrete',
+             rabbit_ha_queues      => 'true',
+             amqp_durable_queues   => 'true',
+             rabbit_host           => '10.0.0.1'}"
+        end
+        it 'configures trove-api with RabbitMQ' do
+          is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_host').with_value('10.0.0.1')
+          is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true')
+          is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('true')
         end
       end
 
@@ -54,45 +78,10 @@ describe 'trove::guestagent' do
         end
         it 'configures trove-guestagent with RabbitMQ' do
           is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_hosts').with_value(['10.0.0.1,10.0.0.2'])
+          is_expected.to contain_trove_guestagent_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true')
         end
       end
 
-      context 'when using qpid' do
-        let :pre_condition do
-          "class { 'trove':
-             nova_proxy_admin_pass => 'verysecrete',
-             rpc_backend           => 'qpid',
-             qpid_hostname         => '10.0.0.1',
-             qpid_username         => 'guest',
-             qpid_password         => 'password'}"
-        end
-        it 'configures trove-guestagent with qpid' do
-          is_expected.to contain_trove_guestagent_config('DEFAULT/rpc_backend').with_value('qpid')
-          is_expected.to contain_trove_guestagent_config('oslo_messaging_qpid/qpid_hostname').with_value('10.0.0.1')
-          is_expected.to contain_trove_guestagent_config('oslo_messaging_qpid/qpid_username').with_value('guest')
-          is_expected.to contain_trove_guestagent_config('oslo_messaging_qpid/qpid_password').with_value('password')
-          is_expected.to contain_trove_guestagent_config('oslo_messaging_qpid/qpid_protocol').with_value('tcp')
-        end
-      end
-
-      context 'when using qpid with SSL enabled' do
-        let :pre_condition do
-          "class { 'trove':
-             nova_proxy_admin_pass => 'verysecrete',
-             rpc_backend           => 'qpid',
-             qpid_hostname         => '10.0.0.1',
-             qpid_username         => 'guest',
-             qpid_password         => 'password',
-             qpid_protocol         => 'ssl'}"
-        end
-        it 'configures trove-guestagent with qpid' do
-          is_expected.to contain_trove_guestagent_config('DEFAULT/rpc_backend').with_value('qpid')
-          is_expected.to contain_trove_guestagent_config('oslo_messaging_qpid/qpid_hostname').with_value('10.0.0.1')
-          is_expected.to contain_trove_guestagent_config('oslo_messaging_qpid/qpid_username').with_value('guest')
-          is_expected.to contain_trove_guestagent_config('oslo_messaging_qpid/qpid_password').with_value('password')
-          is_expected.to contain_trove_guestagent_config('oslo_messaging_qpid/qpid_protocol').with_value('ssl')
-        end
-      end
     end
 
     context 'with custom parameters' do
@@ -168,8 +157,10 @@ describe 'trove::guestagent' do
 
   context 'on Debian platforms' do
     let :facts do
-      { :osfamily       => 'Debian',
-        :processorcount => 8 }
+      @default_facts.merge({
+        :osfamily       => 'Debian',
+        :processorcount => 8
+      })
     end
 
     let :platform_params do
@@ -182,8 +173,10 @@ describe 'trove::guestagent' do
 
   context 'on RedHat platforms' do
     let :facts do
-      { :osfamily       => 'RedHat',
-        :processorcount => 8 }
+      @default_facts.merge({
+        :osfamily       => 'RedHat',
+        :processorcount => 8
+      })
     end
 
     let :platform_params do
