@@ -46,7 +46,7 @@ describe 'trove::taskmanager' do
         is_expected.to contain_package('trove-taskmanager').with(
           :name   => platform_params[:taskmanager_package_name],
           :ensure => 'present',
-          :notify => 'Service[trove-taskmanager]'
+          :tag    => ['openstack', 'trove-package']
         )
       end
 
@@ -66,6 +66,13 @@ describe 'trove::taskmanager' do
         is_expected.to contain_trove_taskmanager_config('DEFAULT/neutron_service_type').with_value('network')
         is_expected.to contain_trove_config('DEFAULT/taskmanager_queue').with_value('taskmanager')
         is_expected.to contain_file('/etc/trove/trove-guestagent.conf')
+        is_expected.to contain_trove_taskmanager_config('DEFAULT/notification_driver').with_value('noop,')
+        is_expected.to contain_trove_taskmanager_config('DEFAULT/notification_topics').with_value('notifications')
+        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/rabbit_userid').with_value('guest')
+        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/rabbit_password').with_value('guest')
+        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(false)
+        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(false)
       end
 
       context 'when set use_guestagent_template to false' do
@@ -91,6 +98,33 @@ describe 'trove::taskmanager' do
         end
         it 'configures trove-taskmanager with RabbitMQ' do
           is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/rabbit_host').with_value('10.0.0.1')
+          is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('false')
+          is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('false')
+
+          # trove taskmanager also configures trove_guestagent.conf by default, ensure rabbit is right there
+          is_expected.to contain_file('/etc/trove/trove-guestagent.conf').with_content(/^rabbit_host=10.0.0.1$/)
+          is_expected.to contain_file('/etc/trove/trove-guestagent.conf').with_content(/^rabbit_port=5672$/)
+          is_expected.to contain_file('/etc/trove/trove-guestagent.conf').with_content(/^rabbit_ha_queues=false$/)
+        end
+      end
+
+      context 'when using a single RabbitMQ server with enable rabbbit ha options' do
+        let :pre_condition do
+          "class { 'trove':
+             nova_proxy_admin_pass => 'verysecrete',
+             rabbit_ha_queues      => 'true',
+             amqp_durable_queues   => 'true',
+             rabbit_host           => '10.0.0.1'}"
+        end
+        it 'configures trove-api with RabbitMQ' do
+          is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/rabbit_host').with_value('10.0.0.1')
+          is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true')
+          is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('true')
+
+          # trove taskmanager also configures trove_guestagent.conf by default, ensure rabbit is right there
+          is_expected.to contain_file('/etc/trove/trove-guestagent.conf').with_content(/^rabbit_host=10.0.0.1$/)
+          is_expected.to contain_file('/etc/trove/trove-guestagent.conf').with_content(/^rabbit_port=5672$/)
+          is_expected.to contain_file('/etc/trove/trove-guestagent.conf').with_content(/^rabbit_ha_queues=true$/)
         end
       end
 
@@ -102,43 +136,11 @@ describe 'trove::taskmanager' do
         end
         it 'configures trove-taskmanager with RabbitMQ' do
           is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/rabbit_hosts').with_value(['10.0.0.1,10.0.0.2'])
-        end
-      end
+          is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true')
 
-      context 'when using qpid' do
-        let :pre_condition do
-          "class { 'trove':
-             nova_proxy_admin_pass => 'verysecrete',
-             rpc_backend           => 'qpid',
-             qpid_hostname         => '10.0.0.1',
-             qpid_username         => 'guest',
-             qpid_password         => 'password'}"
-        end
-        it 'configures trove-taskmanager with qpid' do
-          is_expected.to contain_trove_taskmanager_config('DEFAULT/rpc_backend').with_value('qpid')
-          is_expected.to contain_trove_taskmanager_config('oslo_messaging_qpid/qpid_hostname').with_value('10.0.0.1')
-          is_expected.to contain_trove_taskmanager_config('oslo_messaging_qpid/qpid_username').with_value('guest')
-          is_expected.to contain_trove_taskmanager_config('oslo_messaging_qpid/qpid_password').with_value('password')
-          is_expected.to contain_trove_taskmanager_config('oslo_messaging_qpid/qpid_protocol').with_value('tcp')
-        end
-      end
-
-      context 'when using qpid with SSL enabled' do
-        let :pre_condition do
-          "class { 'trove':
-             nova_proxy_admin_pass => 'verysecrete',
-             rpc_backend           => 'qpid',
-             qpid_hostname         => '10.0.0.1',
-             qpid_username         => 'guest',
-             qpid_password         => 'password',
-             qpid_protocol         => 'ssl'}"
-        end
-        it 'configures trove-taskmanager with qpid' do
-          is_expected.to contain_trove_taskmanager_config('DEFAULT/rpc_backend').with_value('qpid')
-          is_expected.to contain_trove_taskmanager_config('oslo_messaging_qpid/qpid_hostname').with_value('10.0.0.1')
-          is_expected.to contain_trove_taskmanager_config('oslo_messaging_qpid/qpid_username').with_value('guest')
-          is_expected.to contain_trove_taskmanager_config('oslo_messaging_qpid/qpid_password').with_value('password')
-          is_expected.to contain_trove_taskmanager_config('oslo_messaging_qpid/qpid_protocol').with_value('ssl')
+          # trove taskmanager also configures trove_guestagent.conf by default, ensure rabbit is right there
+          is_expected.to contain_file('/etc/trove/trove-guestagent.conf').with_content(/^rabbit_hosts=10.0.0.1,10.0.0.2$/)
+          is_expected.to contain_file('/etc/trove/trove-guestagent.conf').with_content(/^rabbit_ha_queues=true$/)
         end
       end
 
@@ -256,8 +258,10 @@ describe 'trove::taskmanager' do
 
   context 'on Debian platforms' do
     let :facts do
-      { :osfamily       => 'Debian',
-        :processorcount => 8 }
+      @default_facts.merge({
+        :osfamily       => 'Debian',
+        :processorcount => 8
+      })
     end
 
     let :platform_params do
@@ -270,8 +274,10 @@ describe 'trove::taskmanager' do
 
   context 'on RedHat platforms' do
     let :facts do
-      { :osfamily       => 'RedHat',
-        :processorcount => 8 }
+      @default_facts.merge({
+        :osfamily       => 'RedHat',
+        :processorcount => 8
+      })
     end
 
     let :platform_params do
